/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.api;

import jalview.datamodel.SequenceFeature;
import jalview.datamodel.SequenceI;

import java.awt.Color;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;

/**
 * Abstract feature renderer interface
 * 
 * @author JimP
 * 
 */
public interface FeatureRenderer
{

  Color findFeatureColour(Color col, SequenceI sequenceI, int r);

  void featuresAdded();

  Object getFeatureStyle(String ft);

  void setColour(String ft, Object ggc);

  AlignViewportI getViewport();

  FeaturesDisplayedI getFeaturesDisplayed();

  Map<String,Object> getFeatureColours();

  void findAllFeatures(boolean newMadeVisible);

  Map<String,Object> getDisplayedFeatureCols();

  List<String> getFeatureGroups();

  List<String> getGroups(boolean visible);

  void setGroupVisibility(List<String> toset, boolean visible);

  void setGroupVisibility(String group, boolean visible);

  List<SequenceFeature> findFeaturesAtRes(SequenceI sequence, int res);

  boolean isTransparencyAvailable();

  String[] getDisplayedFeatureTypes();

  String[] getDisplayedFeatureGroups();

  void setAllVisible(List<String> featureTypes);

  void setVisible(String featureType);

}
